@@ -7,12 +7,14 @@ use crate::{
         connect_info::{Connected, IntoMakeServiceWithConnectInfo},
         MatchedPath, OriginalUri,
     },
+    response::IntoResponse,
+    response::Redirect,
     response::Response,
     routing::strip_prefix::StripPrefix,
     util::{try_downcast, ByteStr, PercentDecodedByteStr},
     BoxError,
 };
-use http::{Request, StatusCode, Uri};
+use http::{Request, Uri};
 use std::{
     borrow::Cow,
     collections::HashMap,
@@ -161,13 +163,14 @@ where
     }
 
     #[doc = include_str!("../docs/routing/nest.md")]
-    pub fn nest<T>(mut self, path: &str, svc: T) -> Self
+    pub fn nest<T>(mut self, mut path: &str, svc: T) -> Self
     where
         T: Service<Request<B>, Response = Response, Error = Infallible> + Clone + Send + 'static,
         T::Future: Send + 'static,
     {
         if path.is_empty() {
-            panic!("Invalid route: empty path");
+            // nesting at `""` and `"/"` should mean the same thing
+            path = "/";
         }
 
         if path.contains('*') {
@@ -201,10 +204,12 @@ where
 
                 for (id, nested_path) in node.route_id_to_path {
                     let route = routes.remove(&id).unwrap();
-                    let full_path = if &*nested_path == "/" {
-                        path.to_owned()
+                    let full_path: Cow<str> = if &*nested_path == "/" {
+                        path.into()
+                    } else if path == "/" {
+                        (&*nested_path).into()
                     } else {
-                        format!("{}{}", path, nested_path)
+                        format!("{}{}", path, nested_path).into()
                     };
                     self = match route {
                         Endpoint::MethodRouter(method_router) => self.route(
@@ -417,6 +422,9 @@ where
                 Arc::clone(matched_path)
             };
             req.extensions_mut().insert(MatchedPath(matched_path));
+        } else {
+            #[cfg(debug_assertions)]
+            panic!("should always have a matched path for a route id");
         }
 
         let params = match_
@@ -484,12 +492,8 @@ where
                     } else {
                         with_path(req.uri(), &format!("{}/", path))
                     };
-                    let res = Response::builder()
-                        .status(StatusCode::MOVED_PERMANENTLY)
-                        .header(http::header::LOCATION, redirect_to.to_string())
-                        .body(crate::body::empty())
-                        .unwrap();
-                    RouterFuture::from_response(res)
+                    let res = Redirect::permanent(redirect_to);
+                    RouterFuture::from_response(res.into_response())
                 } else {
                     match &self.fallback {
                         Fallback::Default(inner) => {
